"""Example of shallow water wave equation.

This script sets up LWRU2 benchmark with initial condition stated

See also

http://www.cee.cornell.edu/longwave/index.cfm?page=benchmark&problem=2

Depth at western boundary is d = 13.5 cm
"""

import sys
from os import sep
sys.path.append('..'+sep+'..'+sep)

def prepare_timeboundary(filename):
    """Converting benchmark 2 time series to NetCDF sww file.
    """


    print 'Preparing time boundary from %s' %filename
    from Numeric import array

    fid = open(filename)

    #Skip first line
    line = fid.readline()

    lines = fid.readlines()
    fid.close()

    N = len(lines)

    T = zeros(N, Float)  #Time
    Q = zeros(N, Float)  #Values

    for i, line in enumerate(lines):
        fields = line.split()

        T[i] = float(fields[0])
        Q[i] = float(fields[1])

    #Create sww file
    from Scientific.IO.NetCDF import NetCDFFile

    outfile = filename[:-4] + '.sww'
    print 'Writing to', outfile
    fid = NetCDFFile(outfile, 'w')

    fid.institution = 'Geoscience Australia'
    fid.description = 'Input wave for Benchmark 2'
    fid.starttime = 0.0
    fid.createDimension('number_of_timesteps', len(T))
    fid.createVariable('time', Float, ('number_of_timesteps',))
    fid.variables['time'][:] = T

    fid.createVariable('stage', Float, ('number_of_timesteps',))
    fid.variables['stage'][:] = Q[:]

    fid.createVariable('xmomentum', Float, ('number_of_timesteps',))
    fid.variables['xmomentum'][:] = 0.0

    fid.createVariable('ymomentum', Float, ('number_of_timesteps',))
    fid.variables['ymomentum'][:] = 0.0

    fid.close()


# Module imports
from anuga.pyvolution.shallow_water import Domain, Reflective_boundary,\
            File_boundary, Transmissive_Momentum_Set_Stage_boundary
from anuga.pyvolution.mesh_factory import rectangular
from anuga.pyvolution.pmesh2domain import pmesh_to_domain_instance 
from Numeric import array, zeros, Float, allclose
import filenames

picklefile = 'domain.pck'
from cPickle import dump, load

N = 50

#Make mesh
execfile('create_mesh.py')


#Preparing points
from anuga.pyvolution.data_manager import xya2pts
xya2pts(filenames.bathymetry_filename, verbose = True,
        stride = 16,
        z_func = lambda z: -z)


#######################
# Domain

print 'Creating domain from', filenames.mesh_filename
domain = pmesh_to_domain_instance(filenames.mesh_filename, Domain)

print "Number of triangles = ", len(domain)
print 'The extent is ', domain.get_extent()


domain.check_integrity()
domain.default_order = 2

print "Number of triangles = ", len(domain)
domain.store = True    #Store for visualisation purposes

import sys, os
base = os.path.basename(sys.argv[0])
domain.filename, _ = os.path.splitext(base)

#LS code to be included in set_quantity
from anuga.pyvolution import util, least_squares
points, attributes = util.read_xya(filenames.bathymetry_filename[:-4] + '.pts')

#Fit attributes to mesh
vertex_attributes = least_squares.fit_to_mesh(domain.coordinates,
                                              domain.triangles,
                                              points,
                                              attributes['elevation'],
                                              alpha = 0.01,
                                              verbose=True)





